@@ -179,7 +179,7 @@ utils::globalVariables(c("vecg","nComponents","modellags","phiEstimate","y","dat
 #'
 #' # See how holdout and trace parameters influence the forecast
 #' es(M3$N1245$x,model="AAdN",h=8,holdout=FALSE,cfType="MSE")
-#' \dontrun{es(M3$N2568$x,model="MAM",h=18,holdout=TRUE,cfType="MSTFE")}
+#' \dontrun{es(M3$N2568$x,model="MAM",h=18,holdout=TRUE,cfType="TMSE")}
 #'
 #' # Model selection example
 #' es(M3$N1245$x,model="ZZN",ic="AIC",h=8,holdout=FALSE,bounds="a")
@@ -206,7 +206,7 @@ utils::globalVariables(c("vecg","nComponents","modellags","phiEstimate","y","dat
 #' # Exogenous variables in ETS example
 #' \dontrun{x <- cbind(c(rep(0,25),1,rep(0,43)),c(rep(0,10),1,rep(0,58)))
 #' y <- ts(c(M3$N1457$x,M3$N1457$xx),frequency=12)
-#' es(y,h=18,holdout=TRUE,xreg=x,cfType="aMSTFE",intervals="np")
+#' es(y,h=18,holdout=TRUE,xreg=x,cfType="aTMSE",intervals="np")
 #' ourModel <- es(ts(c(M3$N1457$x,M3$N1457$xx),frequency=12),h=18,holdout=TRUE,xreg=x,updateX=TRUE)}
 #'
 #' # This will be the same model as in previous line but estimated on new portion of data
@@ -214,10 +214,10 @@ utils::globalVariables(c("vecg","nComponents","modellags","phiEstimate","y","dat
 #'
 #' # Intermittent data example
 #' x <- rpois(100,0.2)
-#' # Croston's method with the best ETS for demand sizes
-#' es(x,"ZZN",intermittent="croston")
-#' # TSB based on iETS(M,N,N)
-#' es(x,"MNN",intermittent="tsb")
+#' # Intervals-based model (Croston's method) with the best ETS for demand sizes
+#' es(x,"ZZN",intermittent="i")
+#' # Intervals-based model (TSB) on iETS(M,N,N)
+#' es(x,"MNN",intermittent="p")
 #' # Constant probability based on iETS(M,N,N)
 #' es(x,"MNN",intermittent="fixed")
 #' # Best type of intermittent model based on iETS(Z,Z,N)
@@ -230,10 +230,10 @@ utils::globalVariables(c("vecg","nComponents","modellags","phiEstimate","y","dat
 #' @export es
 es <- function(data, model="ZZZ", persistence=NULL, phi=NULL,
                initial=c("optimal","backcasting"), initialSeason=NULL, ic=c("AICc","AIC","BIC"),
-               cfType=c("MSE","MAE","HAM","GMSTFE","MSTFE","MSEh","TFL"),
+               cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE"),
                h=10, holdout=FALSE, cumulative=FALSE,
                intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
-               intermittent=c("none","auto","fixed","croston","tsb","sba"), imodel="MNN",
+               intermittent=c("none","auto","fixed","interval","probability","sba"), imodel="MNN",
                bounds=c("usual","admissible","none"),
                silent=c("all","graph","legend","output","none"),
                xreg=NULL, xregDo=c("use","select"), initialX=NULL,
@@ -1257,7 +1257,7 @@ CreatorES <- function(silent=FALSE,...){
     initialXEstimate <- xregdata$initialXEstimate;
 
     nParamExo <- FXEstimate*length(matFX) + gXEstimate*nrow(vecgX) + initialXEstimate*ncol(matat);
-    nParamIntermittent <- all(intermittent!=c("n","p"))*1;
+    nParamIntermittent <- all(intermittent!=c("n","provided"))*1;
     nParamMax <- nParamMax + nParamExo + nParamIntermittent;
 
     if(xregDo=="u"){
@@ -1376,6 +1376,8 @@ CreatorES <- function(silent=FALSE,...){
             persistence <- 0;
             persistenceEstimate <- FALSE
             warning("We did not have enough observations, so persistence value was set to zero.",call.=FALSE);
+            modelDo <- "select"
+            model <- "ZZZ";
         }
         else{
             stop("Not enough observations... Even for fitting of ETS('ANN')!",call.=FALSE);
@@ -1525,7 +1527,7 @@ CreatorES <- function(silent=FALSE,...){
             cat("Selecting appropriate type of intermittency... ");
         }
 # Prepare stuff for intermittency selection
-        intermittentModelsPool <- c("n","f","c","t");
+        intermittentModelsPool <- c("n","f","i","p");
         intermittentCFs <- intermittentICs <- rep(NA,length(intermittentModelsPool));
         intermittentModelsList <- list(NA);
         intermittentICs[1] <- esValues$icBest;
@@ -1820,25 +1822,22 @@ CreatorES <- function(silent=FALSE,...){
     # Write down the probabilities from intermittent models
     pt <- ts(c(as.vector(pt),as.vector(pt.for)),start=start(data),frequency=datafreq);
     # Write down the number of parameters of imodel
-    if(all(intermittent!=c("n","p")) & !imodelProvided){
+    if(all(intermittent!=c("n","provided")) & !imodelProvided){
         parametersNumber[1,3] <- imodel$nParam;
     }
     # Make nice names for intermittent
     if(intermittent=="f"){
         intermittent <- "fixed";
     }
-    else if(intermittent=="c"){
-        intermittent <- "croston";
+    else if(intermittent=="i"){
+        intermittent <- "interval";
     }
-    else if(intermittent=="t"){
-        intermittent <- "tsb";
+    else if(intermittent=="p"){
+        intermittent <- "probability";
     }
     else if(intermittent=="n"){
         intermittent <- "none";
     }
-    else if(intermittent=="p"){
-        intermittent <- "provided";
-    }
 
     if(!is.null(xregNames)){
         parametersNumber[1,2] <- nParamExo;
