@@ -1,8 +1,6 @@
 utils::globalVariables(c("normalizer","constantValue","constantRequired","constantEstimate","C",
                          "ARValue","ARRequired","AREstimate","MAValue","MARequired","MAEstimate"));
 
-
-
 #' State-Space ARIMA
 #'
 #' Function constructs State-Space ARIMA, estimating AR, MA terms and initial
@@ -174,8 +172,8 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 #'         h=10,holdout=TRUE)}
 #'
 #' # ARIMA(1,1,1) with Mean Squared Trace Forecast Error
-#' \dontrun{ssarima(rnorm(118,100,3),orders=list(ar=1,i=1,ma=1),lags=1,h=18,holdout=TRUE,cfType="MSTFE")
-#' ssarima(rnorm(118,100,3),orders=list(ar=1,i=1,ma=1),lags=1,h=18,holdout=TRUE,cfType="aMSTFE")}
+#' \dontrun{ssarima(rnorm(118,100,3),orders=list(ar=1,i=1,ma=1),lags=1,h=18,holdout=TRUE,cfType="TMSE")
+#' ssarima(rnorm(118,100,3),orders=list(ar=1,i=1,ma=1),lags=1,h=18,holdout=TRUE,cfType="aTMSE")}
 #'
 #' # SARIMA(0,1,1) with exogenous variables
 #' ssarima(rnorm(118,100,3),orders=list(i=1,ma=1),h=18,holdout=TRUE,xreg=c(1:118))
@@ -192,10 +190,10 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 ssarima <- function(data, orders=list(ar=c(0),i=c(1),ma=c(1)), lags=c(1),
                     constant=FALSE, AR=NULL, MA=NULL,
                     initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC"),
-                    cfType=c("MSE","MAE","HAM","GMSTFE","MSTFE","MSEh","TFL"),
+                    cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE"),
                     h=10, holdout=FALSE, cumulative=FALSE,
                     intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
-                    intermittent=c("none","auto","fixed","croston","tsb","sba"), imodel="MNN",
+                    intermittent=c("none","auto","fixed","interval","probability","sba"), imodel="MNN",
                     bounds=c("admissible","none"),
                     silent=c("all","graph","legend","output","none"),
                     xreg=NULL, xregDo=c("use","select"), initialX=NULL,
@@ -546,7 +544,7 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
 
     # Check number of parameters vs data
     nParamExo <- FXEstimate*length(matFX) + gXEstimate*nrow(vecgX) + initialXEstimate*ncol(matat);
-    nParamIntermittent <- all(intermittent!=c("n","p"))*1;
+    nParamIntermittent <- all(intermittent!=c("n","provided"))*1;
     nParamMax <- nParamMax + nParamExo + nParamIntermittent;
 
     if(xregDo=="u"){
@@ -770,25 +768,22 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
     # Write down the probabilities from intermittent models
     pt <- ts(c(as.vector(pt),as.vector(pt.for)),start=start(data),frequency=datafreq);
     # Write down the number of parameters of imodel
-    if(all(intermittent!=c("n","p")) & !imodelProvided){
+    if(all(intermittent!=c("n","provided")) & !imodelProvided){
         parametersNumber[1,3] <- imodel$nParam;
     }
     # Make nice names for intermittent
     if(intermittent=="f"){
         intermittent <- "fixed";
     }
-    else if(intermittent=="c"){
-        intermittent <- "croston";
+    else if(intermittent=="i"){
+        intermittent <- "interval";
     }
-    else if(intermittent=="t"){
-        intermittent <- "tsb";
+    else if(intermittent=="p"){
+        intermittent <- "probability";
     }
     else if(intermittent=="n"){
         intermittent <- "none";
     }
-    else if(intermittent=="p"){
-        intermittent <- "provided";
-    }
 
 # Fill in the rest of matvt
     matvt <- ts(matvt,start=(time(data)[1] - deltat(data)*maxlag),frequency=frequency(data));
